/** @file

hippodraw::PlotTable class implementation

Copyright (C) 2003-2006   The Board of Trustees of The Leland Stanford
Junior University.  All Rights Reserved.

$Id: PlotTable.cxx,v 1.18 2006/04/30 22:20:46 pfkeb Exp $

*/

#include "PlotTable.h"

#include "CanvasView.h"
#include "PlotTableEvent.h"
#include "QtView.h"

#include "datareps/DataRep.h"
#include "graphics/ViewBase.h"
#include "plotters/PlotterBase.h"

#include <qapplication.h>
#include <qpushbutton.h>
#if QT_VERSION < 0x040000
#include <qlistview.h>
#else
#include <q3listview.h>
#endif

#include <qstring.h>

#include <vector>

using std::string;
using std::vector;

using namespace hippodraw;

PlotTable::
PlotTable ()
  : PlotTableBase (),
    m_observer ( 0 ),
    m_browser_mode ( false )
{
}

void
PlotTable::
setCanvas ( CanvasView * canvas )
{
  m_canvas_view = canvas;
  initialize ();
}

void
PlotTable::
initialize ()
{
  m_plot_table->clear();

  const vector < const ViewBase * > & views = m_canvas_view->views ();
  vector < const ViewBase * > :: const_iterator first = views.begin ();

  while ( first != views.end () ) {
    const ViewBase * view = *first++;
    const PlotterBase * plotter = view->getPlotter ();
    QString title ( plotter->getTitle ().c_str() );
    QString x_axis ( plotter->getLabel ( Axes::X ).c_str() );
    QString y_axis ( plotter->getLabel ( Axes::Y ).c_str() );
    QString z_axis ( QString::null );
    if ( plotter->hasAxis ( Axes::Z ) ) {
      const string & z = plotter->getLabel ( Axes::Z );
      z_axis = z.c_str();
    }
    const DataRep * rep = plotter->getDataRep ( 0 );
    const string & t = rep->name ();
    QString type ( t.c_str() );

#if QT_VERSION < 0x040000
    QListViewItem * item 
      =   new QListViewItem ( m_plot_table,
			      title, type, 
			      x_axis, y_axis, z_axis );
    m_view_map [ item ] = view;
#else
    Q3ListViewItem * item 
      =   new Q3ListViewItem ( m_plot_table,
			       title, type, 
			       x_axis, y_axis, z_axis );
    m_view_map [ item ] = view;
#endif
  }
}

void
PlotTable::
#if QT_VERSION < 0x040000
selectionChanged ( QListViewItem * item )
#else
selectionChanged ( Q3ListViewItem * item )
#endif
{
  const ViewBase * view = m_view_map [ item ];
  ViewBase * v = const_cast < ViewBase * > ( view );
  QtView * vv = dynamic_cast < QtView * > ( v );

  m_canvas_view -> setSelectedItem ( vv );
  m_canvas_view -> ensureVisible ( vv );
  if ( m_browser_mode ) {
    copyButton -> setEnabled ( true );
  }
}

void
PlotTable::
setBrowserMode ( bool yes, QWidget * observer )
{
  m_browser_mode = yes;
  m_observer = observer;
  if ( yes == false ) copyButton -> setEnabled ( yes );
}

void
PlotTable::
copyButton_clicked ()
{
  m_canvas_view -> copySelectedToPasteboard ();

  PlotTableEvent * event = new PlotTableEvent ( PlotTableEvent::Copy );
  QApplication::postEvent ( m_observer, event );
}

void
PlotTable::
closeButton_clicked ()
{
  if ( m_browser_mode ) {
    PlotTableEvent * event = new PlotTableEvent ( PlotTableEvent::Close );
    QApplication::postEvent ( m_observer, event );
  }
  m_browser_mode = false;
}
